==> jc-1.4.0.tar.gz: soot/grimp/internal/GRValueBox.h <==
// public class soot.grimp.internal.GRValueBox

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class f52eb55c4fecba44 soot_grimp_internal_GRValueBox
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_AbstractValueBox

#include "soot/AbstractValueBox.h"

#ifndef _JC_soot_grimp_internal_GRValueBox_H_
#define _JC_soot_grimp_internal_GRValueBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GRValueBox$sub_refs	_jc_soot_grimp_internal_GRValueBox$sub_refs;
typedef struct _jc_soot_grimp_internal_GRValueBox$sub_nonrefs	_jc_soot_grimp_internal_GRValueBox$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GRValueBox$refs	_jc_soot_grimp_internal_GRValueBox$refs;
typedef struct _jc_soot_grimp_internal_GRValueBox$nonrefs	_jc_soot_grimp_internal_GRValueBox$nonrefs;
typedef struct _jc_soot_grimp_internal_GRValueBox$object	_jc_soot_grimp_internal_GRValueBox$object;

typedef const struct _jc_soot_grimp_internal_GRValueBox$vmethods	_jc_soot_grimp_internal_GRValueBox$vmethods;
typedef const struct _jc_soot_grimp_internal_GRValueBox$vtable	_jc_soot_grimp_internal_GRValueBox$vtable;
typedef const struct _jc_soot_grimp_internal_GRValueBox$vtype	_jc_soot_grimp_internal_GRValueBox$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GRValueBox$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_grimp_internal_GRValueBox$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_grimp_internal_GRValueBox$method$canContainValue$dd22978795c5cdfb(_jc_env *, struct _jc_soot_grimp_internal_GRValueBox$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GRValueBox$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GRValueBox$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GRValueBox$method_info$canContainValue$dd22978795c5cdfb;
extern _jc_method _jc_soot_grimp_internal_GRValueBox$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GRValueBox$vmethods {
	jboolean	(*canContainValue$dd22978795c5cdfb)(_jc_env *, struct _jc_soot_grimp_internal_GRValueBox$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GRValueBox$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GRValueBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
	_jc_soot_grimp_internal_GRValueBox$vmethods	soot_grimp_internal_GRValueBox;
};

// Vtype
struct _jc_soot_grimp_internal_GRValueBox$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GRValueBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GRValueBox$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GRValueBox$refs {
    _jc_soot_grimp_internal_GRValueBox$sub_refs	soot_grimp_internal_GRValueBox;
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GRValueBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GRValueBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
    _jc_soot_grimp_internal_GRValueBox$sub_nonrefs	soot_grimp_internal_GRValueBox;
};

// Object instance structure
struct _jc_soot_grimp_internal_GRValueBox$object {
	_jc_soot_grimp_internal_GRValueBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GRValueBox$vtype	*vtype;
	_jc_soot_grimp_internal_GRValueBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GRValueBox$vtype _jc_soot_grimp_internal_GRValueBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GRValueBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GRValueBox$class_object;

#endif	/* _JC_soot_grimp_internal_GRValueBox_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GRValueBox.h <==
// public class soot.grimp.internal.GRValueBox

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 95b491953cb1508e soot_AbstractValueBox
// @dep_class f52eb55c4fecba44 soot_grimp_internal_GRValueBox
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_AbstractValueBox

#include "soot/AbstractValueBox.h"

#ifndef _JC_soot_grimp_internal_GRValueBox_H_
#define _JC_soot_grimp_internal_GRValueBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GRValueBox$sub_refs	_jc_soot_grimp_internal_GRValueBox$sub_refs;
typedef struct _jc_soot_grimp_internal_GRValueBox$sub_nonrefs	_jc_soot_grimp_internal_GRValueBox$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GRValueBox$refs	_jc_soot_grimp_internal_GRValueBox$refs;
typedef struct _jc_soot_grimp_internal_GRValueBox$nonrefs	_jc_soot_grimp_internal_GRValueBox$nonrefs;
typedef struct _jc_soot_grimp_internal_GRValueBox$object	_jc_soot_grimp_internal_GRValueBox$object;

typedef const struct _jc_soot_grimp_internal_GRValueBox$vmethods	_jc_soot_grimp_internal_GRValueBox$vmethods;
typedef const struct _jc_soot_grimp_internal_GRValueBox$vtable	_jc_soot_grimp_internal_GRValueBox$vtable;
typedef const struct _jc_soot_grimp_internal_GRValueBox$vtype	_jc_soot_grimp_internal_GRValueBox$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GRValueBox$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_grimp_internal_GRValueBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_grimp_internal_GRValueBox$method$canContainValue$dd22978795c5cdfb(_jc_env *, struct _jc_soot_grimp_internal_GRValueBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GRValueBox$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GRValueBox$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GRValueBox$method_info$canContainValue$dd22978795c5cdfb;
extern _jc_method _jc_soot_grimp_internal_GRValueBox$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GRValueBox$vmethods {
	jboolean	(*canContainValue$dd22978795c5cdfb)(_jc_env *, struct _jc_soot_grimp_internal_GRValueBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GRValueBox$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GRValueBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractValueBox$vmethods	soot_AbstractValueBox;
	_jc_soot_grimp_internal_GRValueBox$vmethods	soot_grimp_internal_GRValueBox;
};

// Vtype
struct _jc_soot_grimp_internal_GRValueBox$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GRValueBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GRValueBox$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GRValueBox$refs {
    _jc_soot_grimp_internal_GRValueBox$sub_refs	soot_grimp_internal_GRValueBox;
    _jc_soot_AbstractValueBox$sub_refs	soot_AbstractValueBox;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GRValueBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GRValueBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractValueBox$sub_nonrefs	soot_AbstractValueBox;
    _jc_soot_grimp_internal_GRValueBox$sub_nonrefs	soot_grimp_internal_GRValueBox;
};

// Object instance structure
struct _jc_soot_grimp_internal_GRValueBox$object {
	_jc_soot_grimp_internal_GRValueBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GRValueBox$vtype	*vtype;
	_jc_soot_grimp_internal_GRValueBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GRValueBox$vtype _jc_soot_grimp_internal_GRValueBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GRValueBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GRValueBox$class_object;

#endif	/* _JC_soot_grimp_internal_GRValueBox_H_ */
